==> hbase-1.7.1-src.tar.gz: hbase-1.7.1/hbase-client/src/main/java/org/apache/hadoop/hbase/DoNotRetryIOException.java <==
/**
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.hbase;

import org.apache.hadoop.hbase.classification.InterfaceAudience;
import org.apache.hadoop.hbase.classification.InterfaceStability;
import org.apache.hadoop.hbase.HBaseIOException;

/**
 * Subclass if exception is not meant to be retried: e.g.
 * {@link org.apache.hadoop.hbase.UnknownScannerException}
 */
@InterfaceAudience.Public
@InterfaceStability.Stable
public class DoNotRetryIOException extends HBaseIOException {
  // TODO: This would be more useful as a marker interface than as a class.
  private static final long serialVersionUID = 1197446454511704139L;

  public DoNotRetryIOException() {
    super();
  }

  /**
   * @param message the message for this exception
   */
  public DoNotRetryIOException(String message) {
    super(message);
  }

  /**
   * @param message the message for this exception
   * @param throwable the {@link Throwable} to use for this exception
   */
  public DoNotRetryIOException(String message, Throwable throwable) {
    super(message, throwable);
  }

  /**
   * @param throwable the {@link Throwable} to use for this exception
   */
  public DoNotRetryIOException(Throwable throwable) {
    super(throwable);
  }
}

==> hbase-2.3.7-src.tar.gz: hbase-2.3.7/hbase-client/src/main/java/org/apache/hadoop/hbase/DoNotRetryIOException.java <==
/**
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.hbase;

import org.apache.yetus.audience.InterfaceAudience;

/**
 * Subclass if exception is not meant to be retried: e.g.
 * {@link org.apache.hadoop.hbase.UnknownScannerException}
 */
@InterfaceAudience.Public
public class DoNotRetryIOException extends HBaseIOException {
  // TODO: This would be more useful as a marker interface than as a class.
  private static final long serialVersionUID = 1197446454511704139L;

  public DoNotRetryIOException() {
    super();
  }

  /**
   * @param message the message for this exception
   */
  public DoNotRetryIOException(String message) {
    super(message);
  }

  /**
   * @param message the message for this exception
   * @param throwable the {@link Throwable} to use for this exception
   */
  public DoNotRetryIOException(String message, Throwable throwable) {
    super(message, throwable);
  }

  /**
   * @param throwable the {@link Throwable} to use for this exception
   */
  public DoNotRetryIOException(Throwable throwable) {
    super(throwable);
  }
}
